package com.zhyc.module.biosafety.mapper;

import java.util.List;

import com.zhyc.module.biosafety.domain.Treatment;
import org.apache.ibatis.annotations.Mapper;

/**
 * 治疗记录Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@Mapper
public interface TreatmentMapper 
{
    /**
     * 查询治疗记录
     * 
     * @param id 治疗记录主键
     * @return 治疗记录
     */
    public Treatment selectTreatmentById(Long id);

    /**
     * 查询治疗记录列表
     * 
     * @param treatment 治疗记录
     * @return 治疗记录集合
     */
    public List<Treatment> selectTreatmentList(Treatment treatment);

    /**
     * 新增治疗记录
     * 
     * @param treatment 治疗记录
     * @return 结果
     */
    public int insertTreatment(Treatment treatment);

    /**
     * 修改治疗记录
     * 
     * @param treatment 治疗记录
     * @return 结果
     */
    public int updateTreatment(Treatment treatment);

    /**
     * 删除治疗记录
     * 
     * @param id 治疗记录主键
     * @return 结果
     */
    public int deleteTreatmentById(Long id);

    /**
     * 批量删除治疗记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTreatmentByIds(Long[] ids);

    int insertTreatmentList(List<Treatment> treatments);


    List<Treatment> selectTreatmentStatus(Long sheepId);
}
